SELECT create_cryptokey('test', 16, 'xyz')
\gset

SELECT change_cryptokey_password('test', 'xyz', 'abc');

-- set and test server variable
SELECT set_cryptokey('test', 'abc');
SHOW pgcryptokey.key_id;
SHOW pgcryptokey.name;
SELECT length(current_setting('pgcryptokey.key'));

SELECT length(get_cryptokey('test', 'abc'));

-- access non-existant key
SELECT set_cryptokey(700, 'abc');

-- use both key access methods
SELECT pgp_sym_decrypt(pgp_sym_encrypt('my test', current_setting('pgcryptokey.key')), get_cryptokey('test', 'abc'));

-- use cryptokey in a table
CREATE TEMPORARY TABLE cryptokey_sample (data BYTEA);

INSERT INTO cryptokey_sample VALUES (pgp_sym_encrypt('my data', get_cryptokey('test', 'abc')));

SELECT pgp_sym_decrypt(data, get_cryptokey('test', 'abc'))
FROM cryptokey_sample;

-- rotate keys and test
SELECT supersede_cryptokey('test', 16, 'abc');

-- use this password for all future access
SET pgcryptokey.default_password = 'abc';

SELECT set_cryptokey('test');

UPDATE cryptokey_sample SET data = reencrypt_data(
	data, :create_cryptokey, current_setting('pgcryptokey.key_id')::integer);

SELECT pgp_sym_decrypt(data, get_cryptokey('test'))
FROM cryptokey_sample;

-- must drop superseded key first to avoid notice
SELECT drop_cryptokey(:create_cryptokey);
SELECT drop_cryptokey('test');
